==> pytauri-0.3.0.tar.gz: pytauri-0.3.0/src/pytauri/ffi/webview.py <==
# ruff: noqa: D102

"""[tauri::webview](https://docs.rs/tauri/latest/tauri/webview/index.html)"""

from typing import (
    TYPE_CHECKING,
    Callable,
    Optional,
    final,
)

from typing_extensions import Self

from pytauri.ffi._ext_mod import pytauri_mod

__all__ = ["Webview", "WebviewWindow"]

_webview_mod = pytauri_mod.webview


if TYPE_CHECKING:
    from pytauri.ffi import PositionType
    from pytauri.ffi.menu import ImplContextMenu, Menu, MenuEvent
    from pytauri.ffi.window import Window
    from pytauri.image import Image

    @final
    class WebviewWindow:
        """[tauri::webview::WebviewWindow](https://docs.rs/tauri/latest/tauri/webview/struct.WebviewWindow.html)"""

        def run_on_main_thread(self, handler: Callable[[], object], /) -> None:
            """Runs the given closure on the main thread.

            !!! warning
                `handler` has the same restrictions as [App.run][pytauri.App.run].
            """
            ...

        def label(self) -> str: ...
        def on_menu_event(
            self, handler: Callable[["Self", "MenuEvent"], None], /
        ) -> None:
            """Registers a global menu event listener.

            !!! warning
                `handler` has the same restrictions as [App.run][pytauri.App.run].
            """

        def menu(self) -> Optional[Menu]: ...
        def set_menu(self, menu: Menu, /) -> Optional[Menu]: ...
        def remove_menu(self) -> Optional[Menu]: ...
        def hide_menu(self) -> None: ...
        def show_menu(self) -> None: ...
        def is_menu_visible(self) -> bool: ...
        def popup_menu(self, menu: ImplContextMenu, /) -> None: ...
        def popup_menu_at(
            self, menu: ImplContextMenu, position: PositionType, /
        ) -> None: ...
        def is_fullscreen(self) -> bool: ...
        def is_minimized(self) -> bool: ...
        def is_maximized(self) -> bool: ...
        def is_focused(self) -> bool: ...
        def is_decorated(self) -> bool: ...
        def is_resizable(self) -> bool: ...
        def is_enabled(self) -> bool: ...
        def is_maximizable(self) -> bool: ...
        def is_minimizable(self) -> bool: ...
        def is_closable(self) -> bool: ...
        def is_visible(self) -> bool: ...
        def title(self) -> str: ...
        def center(self) -> None: ...
        def set_resizable(self, resizable: bool, /) -> None: ...
        def set_enabled(self, enabled: bool, /) -> None: ...
        def set_maximizable(self, maximizable: bool, /) -> None: ...
        def set_minimizable(self, minimizable: bool, /) -> None: ...
        def set_closable(self, closable: bool, /) -> None: ...
        def set_title(self, title: str, /) -> None: ...
        def maximize(self) -> None: ...
        def unmaximize(self) -> None: ...
        def minimize(self) -> None: ...
        def unminimize(self) -> None: ...
        def show(self) -> None: ...
        def hide(self) -> None: ...
        def close(self) -> None: ...
        def destroy(self) -> None: ...
        def set_decorations(self, decorations: bool, /) -> None: ...
        def set_shadow(self, shadow: bool, /) -> None: ...
        def set_always_on_bottom(self, always_on_bottom: bool, /) -> None: ...
        def set_always_on_top(self, always_on_top: bool, /) -> None: ...
        def set_visible_on_all_workspaces(
            self, visible_on_all_workspaces: bool, /
        ) -> None: ...
        def set_content_protected(self, protected: bool, /) -> None: ...
        def set_fullscreen(self, fullscreen: bool, /) -> None: ...
        def set_focus(self) -> None: ...
        def set_icon(self, icon: Image, /) -> None: ...
        def set_skip_taskbar(self, skip: bool, /) -> None: ...
        def set_cursor_grab(self, grab: bool, /) -> None: ...
        def set_cursor_visible(self, visible: bool, /) -> None: ...
        def set_ignore_cursor_events(self, ignore: bool, /) -> None: ...
        def start_dragging(self) -> None: ...
        def set_badge_count(self, count: Optional[int], /) -> None: ...
        def print(self) -> None: ...
        def url(self) -> str: ...
        def eval(self, js: str, /) -> None: ...
        def set_zoom(self, scale_factor: float, /) -> None: ...
        def clear_all_browsing_data(self) -> None: ...
        def as_ref_webview(self) -> "Webview": ...

    @final
    class Webview:
        """[tauri::webview::Webview](https://docs.rs/tauri/latest/tauri/webview/struct.Webview.html)"""

        def window(self) -> "Window": ...

else:
    WebviewWindow = _webview_mod.WebviewWindow
    Webview = _webview_mod.Webview

==> pytauri-0.4.0.tar.gz: pytauri-0.4.0/src/pytauri/ffi/webview.py <==
# ruff: noqa: D102

"""[tauri::webview](https://docs.rs/tauri/latest/tauri/webview/index.html)"""

from typing import (
    TYPE_CHECKING,
    Callable,
    Optional,
    final,
)

from typing_extensions import Self

from pytauri.ffi._ext_mod import pytauri_mod

__all__ = ["Webview", "WebviewWindow"]

_webview_mod = pytauri_mod.webview


if TYPE_CHECKING:
    from pytauri.ffi import PositionType, Url
    from pytauri.ffi.menu import ImplContextMenu, Menu, MenuEvent
    from pytauri.ffi.window import Window
    from pytauri.image import Image

    @final
    class WebviewWindow:
        """[tauri::webview::WebviewWindow](https://docs.rs/tauri/latest/tauri/webview/struct.WebviewWindow.html)"""

        def run_on_main_thread(self, handler: Callable[[], object], /) -> None:
            """Runs the given closure on the main thread.

            !!! warning
                `handler` has the same restrictions as [App.run][pytauri.App.run].
            """
            ...

        def label(self) -> str: ...
        def on_menu_event(
            self, handler: Callable[["Self", "MenuEvent"], None], /
        ) -> None:
            """Registers a global menu event listener.

            !!! warning
                `handler` has the same restrictions as [App.run][pytauri.App.run].
            """

        def menu(self) -> Optional[Menu]: ...
        def set_menu(self, menu: Menu, /) -> Optional[Menu]: ...
        def remove_menu(self) -> Optional[Menu]: ...
        def hide_menu(self) -> None: ...
        def show_menu(self) -> None: ...
        def is_menu_visible(self) -> bool: ...
        def popup_menu(self, menu: ImplContextMenu, /) -> None: ...
        def popup_menu_at(
            self, menu: ImplContextMenu, position: PositionType, /
        ) -> None: ...
        def is_fullscreen(self) -> bool: ...
        def is_minimized(self) -> bool: ...
        def is_maximized(self) -> bool: ...
        def is_focused(self) -> bool: ...
        def is_decorated(self) -> bool: ...
        def is_resizable(self) -> bool: ...
        def is_enabled(self) -> bool: ...
        def is_maximizable(self) -> bool: ...
        def is_minimizable(self) -> bool: ...
        def is_closable(self) -> bool: ...
        def is_visible(self) -> bool: ...
        def title(self) -> str: ...
        def center(self) -> None: ...
        def set_resizable(self, resizable: bool, /) -> None: ...
        def set_enabled(self, enabled: bool, /) -> None: ...
        def set_maximizable(self, maximizable: bool, /) -> None: ...
        def set_minimizable(self, minimizable: bool, /) -> None: ...
        def set_closable(self, closable: bool, /) -> None: ...
        def set_title(self, title: str, /) -> None: ...
        def maximize(self) -> None: ...
        def unmaximize(self) -> None: ...
        def minimize(self) -> None: ...
        def unminimize(self) -> None: ...
        def show(self) -> None: ...
        def hide(self) -> None: ...
        def close(self) -> None: ...
        def destroy(self) -> None: ...
        def set_decorations(self, decorations: bool, /) -> None: ...
        def set_shadow(self, shadow: bool, /) -> None: ...
        def set_always_on_bottom(self, always_on_bottom: bool, /) -> None: ...
        def set_always_on_top(self, always_on_top: bool, /) -> None: ...
        def set_visible_on_all_workspaces(
            self, visible_on_all_workspaces: bool, /
        ) -> None: ...
        def set_content_protected(self, protected: bool, /) -> None: ...
        def set_fullscreen(self, fullscreen: bool, /) -> None: ...
        def set_focus(self) -> None: ...
        def set_icon(self, icon: Image, /) -> None: ...
        def set_skip_taskbar(self, skip: bool, /) -> None: ...
        def set_cursor_grab(self, grab: bool, /) -> None: ...
        def set_cursor_visible(self, visible: bool, /) -> None: ...
        def set_ignore_cursor_events(self, ignore: bool, /) -> None: ...
        def start_dragging(self) -> None: ...
        def set_badge_count(self, count: Optional[int], /) -> None: ...
        def print(self) -> None: ...
        def url(self) -> Url: ...
        def navigate(self, url: Url, /) -> None: ...
        def eval(self, js: str, /) -> None: ...
        def set_zoom(self, scale_factor: float, /) -> None: ...
        def clear_all_browsing_data(self) -> None: ...
        def as_ref_webview(self) -> "Webview": ...

    @final
    class Webview:
        """[tauri::webview::Webview](https://docs.rs/tauri/latest/tauri/webview/struct.Webview.html)"""

        def window(self) -> "Window": ...

else:
    WebviewWindow = _webview_mod.WebviewWindow
    Webview = _webview_mod.Webview
